@@ -16,17 +16,8 @@ in the source distribution for its full text.
 #include <ctype.h>
 #include <string.h>
 
-/*{
-#include "Panel.h"
 
-typedef struct AvailableColumnsPanel_ {
-   Panel super;
-   Panel* columns;
-} AvailableColumnsPanel;
-
-}*/
-
-static const char* AvailableColumnsFunctions[] = {"      ", "      ", "      ", "      ", "Add   ", "      ", "      ", "      ", "      ", "Done  ", NULL};
+static const char* const AvailableColumnsFunctions[] = {"      ", "      ", "      ", "      ", "Add   ", "      ", "      ", "      ", "      ", "Done  ", NULL};
 
 static void AvailableColumnsPanel_delete(Object* object) {
    Panel* super = (Panel*) object;
@@ -81,7 +72,7 @@ AvailableColumnsPanel* AvailableColumnsPanel_new(Panel* columns) {
    for (int i = 1; i < Platform_numberOfFields; i++) {
       if (i != COMM && Process_fields[i].description) {
          char description[256];
-         snprintf(description, sizeof(description), "%s - %s", Process_fields[i].name, Process_fields[i].description);
+         xSnprintf(description, sizeof(description), "%s - %s", Process_fields[i].name, Process_fields[i].description);
          Panel_add(super, (Object*) ListItem_new(description, i));
       }
    }
