@@ -12,17 +12,6 @@ in the source distribution for its full text.
 #include <assert.h>
 #include <stdlib.h>
 
-/*{
-#include "Object.h"
-
-typedef struct CheckItem_ {
-   Object super;
-   char* text;
-   bool* ref;
-   bool value;
-} CheckItem;
-
-}*/
 
 static void CheckItem_delete(Object* cast) {
    CheckItem* this = (CheckItem*)cast;
@@ -66,14 +55,14 @@ CheckItem* CheckItem_newByVal(char* text, bool value) {
 }
 
 void CheckItem_set(CheckItem* this, bool value) {
-   if (this->ref) 
+   if (this->ref)
       *(this->ref) = value;
    else
       this->value = value;
 }
 
 bool CheckItem_get(CheckItem* this) {
-   if (this->ref) 
+   if (this->ref)
       return *(this->ref);
    else
       return this->value;
