@@ -16,30 +16,6 @@ in the source distribution for its full text.
 #include <string.h>
 #include <stdlib.h>
 
-/*{
-#include "Meter.h"
-#include "Settings.h"
-#include "Vector.h"
-
-typedef struct Header_ {
-   Vector** columns;
-   Settings* settings;
-   struct ProcessList_* pl;
-   int nrColumns;
-   int pad;
-   int height;
-} Header;
-
-}*/
-
-#ifndef MAX
-#define MAX(a,b) ((a)>(b)?(a):(b))
-#endif
-
-#ifndef Header_forEachColumn
-#define Header_forEachColumn(this_, i_) for (int (i_)=0; (i_) < (this_)->nrColumns; ++(i_))
-#endif
-
 Header* Header_new(struct ProcessList_* pl, Settings* settings, int nrColumns) {
    Header* this = xCalloc(1, sizeof(Header));
    this->columns = xCalloc(nrColumns, sizeof(Vector*));
@@ -76,17 +52,17 @@ void Header_populateFromSettings(Header* this) {
 void Header_writeBackToSettings(const Header* this) {
    Header_forEachColumn(this, col) {
       MeterColumnSettings* colSettings = &this->settings->columns[col];
-      
+
       String_freeArray(colSettings->names);
       free(colSettings->modes);
-      
+
       Vector* vec = this->columns[col];
       int len = Vector_size(vec);
-      
+
       colSettings->names = xCalloc(len+1, sizeof(char*));
       colSettings->modes = xCalloc(len, sizeof(int));
       colSettings->len = len;
-      
+
       for (int i = 0; i < len; i++) {
          Meter* meter = (Meter*) Vector_get(vec, i);
          char* name = xCalloc(64, sizeof(char));
@@ -120,6 +96,8 @@ MeterModeId Header_addMeterByName(Header* this, char* name, int column) {
          break;
       }
    }
+   if (paren)
+      *paren = '(';
    return mode;
 }
 
@@ -152,7 +130,7 @@ char* Header_readMeterName(Header* this, int i, int column) {
    int nameLen = strlen(Meter_name(meter));
    int len = nameLen + 100;
    char* name = xMalloc(len);
-   strncpy(name, Meter_name(meter), nameLen);
+   memcpy(name, Meter_name(meter), nameLen);
    name[nameLen] = '\0';
    if (meter->param)
       xSnprintf(name + nameLen, len - nameLen, "(%d)", meter->param);
@@ -186,7 +164,7 @@ void Header_draw(const Header* this) {
    }
    int width = COLS / this->nrColumns - (pad * this->nrColumns - 1) - 1;
    int x = pad;
-   
+
    Header_forEachColumn(this, col) {
       Vector* meters = this->columns[col];
       for (int y = (pad / 2), i = 0; i < Vector_size(meters); i++) {
@@ -209,7 +187,7 @@ int Header_calculateHeight(Header* this) {
          Meter* meter = (Meter*) Vector_get(meters, i);
          height += meter->h;
       }
-      maxHeight = MAX(maxHeight, height);
+      maxHeight = MAXIMUM(maxHeight, height);
    }
    this->height = maxHeight;
    this->pad = pad;
