@@ -23,30 +23,6 @@ in the source distribution for its full text.
 #include <sys/types.h>
 #include <sys/wait.h>
 
-/*{
-#include "InfoScreen.h"
-
-typedef struct OpenFiles_Data_ {
-   char* data[256];
-} OpenFiles_Data;
-
-typedef struct OpenFiles_ProcessData_ {
-   OpenFiles_Data data;
-   int error;
-   struct OpenFiles_FileData_* files;
-} OpenFiles_ProcessData;
-
-typedef struct OpenFiles_FileData_ {
-   OpenFiles_Data data;
-   struct OpenFiles_FileData_* next;
-} OpenFiles_FileData;
-
-typedef struct OpenFilesScreen_ {
-   InfoScreen super;
-   pid_t pid;
-} OpenFilesScreen;
-
-}*/
 
 InfoScreenClass OpenFilesScreen_class = {
    .super = {
@@ -124,6 +100,7 @@ static OpenFiles_ProcessData* OpenFilesScreen_getProcessData(pid_t pid) {
       item->data[cmd] = xStrdup(line + 1);
       free(line);
    }
+   fclose(fd);
    int wstatus;
    if (waitpid(child, &wstatus, 0) == -1) {
       pdata->error = 1;
