@@ -1,6 +1,7 @@
 /*
 htop - Process.c
 (C) 2004-2015 Hisham H. Muhammad
+(C) 2020 Red Hat, Inc.  All Rights Reserved.
 Released under the GNU GPL, see the COPYING file
 in the source distribution for its full text.
 */
@@ -8,6 +9,8 @@ in the source distribution for its full text.
 #include "Process.h"
 #include "Settings.h"
 
+#include "config.h"
+
 #include "CRT.h"
 #include "StringUtils.h"
 #include "RichString.h"
@@ -18,7 +21,6 @@ in the source distribution for its full text.
 #include <sys/resource.h>
 #include <sys/param.h>
 #include <sys/stat.h>
-#include <sys/types.h>
 #include <unistd.h>
 #include <stdlib.h>
 #include <signal.h>
@@ -30,172 +32,12 @@ in the source distribution for its full text.
 #include <math.h>
 #ifdef MAJOR_IN_MKDEV
 #include <sys/mkdev.h>
-#elif defined(MAJOR_IN_SYSMACROS) || \
-   (defined(HAVE_SYS_SYSMACROS_H) && HAVE_SYS_SYSMACROS_H)
+#elif defined(MAJOR_IN_SYSMACROS)
 #include <sys/sysmacros.h>
 #endif
 
-#ifdef __ANDROID__
-#define SYS_ioprio_get __NR_ioprio_get
-#define SYS_ioprio_set __NR_ioprio_set
-#endif
-
-// On Linux, this works only with glibc 2.1+. On earlier versions
-// the behavior is similar to have a hardcoded page size.
-#ifndef PAGE_SIZE
-#define PAGE_SIZE ( sysconf(_SC_PAGESIZE) )
-#endif
-#define PAGE_SIZE_KB ( PAGE_SIZE / ONE_K )
-
-/*{
-#include "Object.h"
-
-#include <sys/types.h>
-
-#define PROCESS_FLAG_IO 0x0001
-
-typedef enum ProcessFields {
-   NULL_PROCESSFIELD = 0,
-   PID = 1,
-   COMM = 2,
-   STATE = 3,
-   PPID = 4,
-   PGRP = 5,
-   SESSION = 6,
-   TTY_NR = 7,
-   TPGID = 8,
-   MINFLT = 10,
-   MAJFLT = 12,
-   PRIORITY = 18,
-   NICE = 19,
-   STARTTIME = 21,
-   PROCESSOR = 38,
-   M_SIZE = 39,
-   M_RESIDENT = 40,
-   ST_UID = 46,
-   PERCENT_CPU = 47,
-   PERCENT_MEM = 48,
-   USER = 49,
-   TIME = 50,
-   NLWP = 51,
-   TGID = 52,
-} ProcessField;
-
-typedef struct ProcessPidColumn_ {
-   int id;
-   char* label;
-} ProcessPidColumn;
-
-typedef struct Process_ {
-   Object super;
-
-   struct Settings_* settings;
-
-   unsigned long long int time;
-   pid_t pid;
-   pid_t ppid;
-   pid_t tgid;
-   char* comm;
-   int commLen;
-   int indent;
-
-   int basenameOffset;
-   bool updated;
-
-   char state;
-   bool tag;
-   bool showChildren;
-   bool show;
-   unsigned int pgrp;
-   unsigned int session;
-   unsigned int tty_nr;
-   int tpgid;
-   uid_t st_uid;
-   unsigned long int flags;
-   int processor;
-
-   float percent_cpu;
-   float percent_mem;
-   char* user;
-
-   long int priority;
-   long int nice;
-   long int nlwp;
-   char starttime_show[8];
-   time_t starttime_ctime;
-
-   long m_size;
-   long m_resident;
-
-   int exit_signal;
-
-   unsigned long int minflt;
-   unsigned long int majflt;
-   #ifdef DEBUG
-   long int itrealvalue;
-   unsigned long int vsize;
-   long int rss;
-   unsigned long int rlim;
-   unsigned long int startcode;
-   unsigned long int endcode;
-   unsigned long int startstack;
-   unsigned long int kstkesp;
-   unsigned long int kstkeip;
-   unsigned long int signal;
-   unsigned long int blocked;
-   unsigned long int sigignore;
-   unsigned long int sigcatch;
-   unsigned long int wchan;
-   unsigned long int nswap;
-   unsigned long int cnswap;
-   #endif
-
-} Process;
-
-typedef struct ProcessFieldData_ {
-   const char* name;
-   const char* title;
-   const char* description;
-   int flags;
-} ProcessFieldData;
-
-// Implemented in platform-specific code:
-void Process_writeField(Process* this, RichString* str, ProcessField field);
-long Process_compare(const void* v1, const void* v2);
-void Process_delete(Object* cast);
-bool Process_isThread(Process* this);
-extern ProcessFieldData Process_fields[];
-extern ProcessPidColumn Process_pidColumns[];
-extern char Process_pidFormat[20];
-
-typedef Process*(*Process_New)(struct Settings_*);
-typedef void (*Process_WriteField)(Process*, RichString*, ProcessField);
-
-typedef struct ProcessClass_ {
-   const ObjectClass super;
-   const Process_WriteField writeField;
-} ProcessClass;
-
-#define As_Process(this_)              ((ProcessClass*)((this_)->super.klass))
-
-#define Process_getParentPid(process_)    (process_->tgid == process_->pid ? process_->ppid : process_->tgid)
-
-#define Process_isChildOf(process_, pid_) (process_->tgid == pid_ || (process_->tgid == process_->pid && process_->ppid == pid_))
-
-#define Process_sortState(state) ((state) == 'I' ? 0x100 : (state))
-
-}*/
-
 static int Process_getuid = -1;
 
-#define ONE_K 1024L
-#define ONE_M (ONE_K * ONE_K)
-#define ONE_G (ONE_M * ONE_K)
-
-#define ONE_DECIMAL_K 1000L
-#define ONE_DECIMAL_M (ONE_DECIMAL_K * ONE_DECIMAL_K)
-#define ONE_DECIMAL_G (ONE_DECIMAL_M * ONE_DECIMAL_K)
-
 char Process_pidFormat[20] = "%7d ";
 
 static char Process_titleBuffer[20][20];
@@ -216,7 +58,7 @@ void Process_setupColumnWidths() {
 void Process_humanNumber(RichString* str, unsigned long number, bool coloring) {
    char buffer[11];
    int len;
-   
+
    int largeNumberColor = CRT_colors[LARGE_NUMBER];
    int processMegabytesColor = CRT_colors[PROCESS_MEGABYTES];
    int processColor = CRT_colors[PROCESS];
@@ -224,11 +66,11 @@ void Process_humanNumber(RichString* str, unsigned long number, bool coloring) {
       largeNumberColor = CRT_colors[PROCESS];
       processMegabytesColor = CRT_colors[PROCESS];
    }
- 
+
    if(number >= (10 * ONE_DECIMAL_M)) {
       #ifdef __LP64__
       if(number >= (100 * ONE_DECIMAL_G)) {
-         len = snprintf(buffer, 10, "%4ldT ", number / ONE_G);
+         len = snprintf(buffer, 10, "%4luT ", number / ONE_G);
          RichString_appendn(str, largeNumberColor, buffer, len);
          return;
       } else if (number >= (1000 * ONE_DECIMAL_M)) {
@@ -238,7 +80,7 @@ void Process_humanNumber(RichString* str, unsigned long number, bool coloring) {
       }
       #endif
       if(number >= (100 * ONE_DECIMAL_M)) {
-         len = snprintf(buffer, 10, "%4ldG ", number / ONE_M);
+         len = snprintf(buffer, 10, "%4luG ", number / ONE_M);
          RichString_appendn(str, largeNumberColor, buffer, len);
          return;
       }
@@ -246,11 +88,11 @@ void Process_humanNumber(RichString* str, unsigned long number, bool coloring) {
       RichString_appendn(str, largeNumberColor, buffer, len);
       return;
    } else if (number >= 100000) {
-      len = snprintf(buffer, 10, "%4ldM ", number / ONE_K);
+      len = snprintf(buffer, 10, "%4luM ", number / ONE_K);
       RichString_appendn(str, processMegabytesColor, buffer, len);
       return;
    } else if (number >= 1000) {
-      len = snprintf(buffer, 10, "%2ld", number/1000);
+      len = snprintf(buffer, 10, "%2lu", number/1000);
       RichString_appendn(str, processMegabytesColor, buffer, len);
       number %= 1000;
       len = snprintf(buffer, 10, "%03lu ", number);
@@ -277,8 +119,15 @@ void Process_colorNumber(RichString* str, unsigned long long number, bool colori
    if ((long long) number == -1LL) {
       int len = snprintf(buffer, 13, "    no perm ");
       RichString_appendn(str, CRT_colors[PROCESS_SHADOW], buffer, len);
-   } else if (number > 10000000000) {
-      xSnprintf(buffer, 13, "%11lld ", number / 1000);
+   } else if (number >= 100000LL * ONE_DECIMAL_T) {
+      xSnprintf(buffer, 13, "%11llu ", number / ONE_DECIMAL_G);
+      RichString_appendn(str, largeNumberColor, buffer, 12);
+   } else if (number >= 100LL * ONE_DECIMAL_T) {
+      xSnprintf(buffer, 13, "%11llu ", number / ONE_DECIMAL_M);
+      RichString_appendn(str, largeNumberColor, buffer, 8);
+      RichString_appendn(str, processMegabytesColor, buffer+8, 4);
+   } else if (number >= 10LL * ONE_DECIMAL_G) {
+      xSnprintf(buffer, 13, "%11llu ", number / ONE_DECIMAL_K);
       RichString_appendn(str, largeNumberColor, buffer, 5);
       RichString_appendn(str, processMegabytesColor, buffer+5, 3);
       RichString_appendn(str, processColor, buffer+8, 4);
@@ -358,14 +207,17 @@ void Process_outputRate(RichString* str, char* buffer, int n, double rate, int c
    } else if (rate < ONE_K) {
       int len = snprintf(buffer, n, "%7.2f B/s ", rate);
       RichString_appendn(str, processColor, buffer, len);
-   } else if (rate < ONE_K * ONE_K) {
+   } else if (rate < ONE_M) {
       int len = snprintf(buffer, n, "%7.2f K/s ", rate / ONE_K);
       RichString_appendn(str, processColor, buffer, len);
-   } else if (rate < ONE_K * ONE_K * ONE_K) {
-      int len = snprintf(buffer, n, "%7.2f M/s ", rate / ONE_K / ONE_K);
+   } else if (rate < ONE_G) {
+      int len = snprintf(buffer, n, "%7.2f M/s ", rate / ONE_M);
       RichString_appendn(str, processMegabytesColor, buffer, len);
+   } else if (rate < ONE_T) {
+      int len = snprintf(buffer, n, "%7.2f G/s ", rate / ONE_G);
+      RichString_appendn(str, largeNumberColor, buffer, len);
    } else {
-      int len = snprintf(buffer, n, "%7.2f G/s ", rate / ONE_K / ONE_K / ONE_K);
+      int len = snprintf(buffer, n, "%7.2f T/s ", rate / ONE_T);
       RichString_appendn(str, largeNumberColor, buffer, len);
    }
 }
@@ -380,9 +232,9 @@ void Process_writeField(Process* this, RichString* str, ProcessField field) {
    switch (field) {
    case PERCENT_CPU: {
       if (this->percent_cpu > 999.9) {
-         xSnprintf(buffer, n, "%4d ", (unsigned int)this->percent_cpu); 
+         xSnprintf(buffer, n, "%4u ", (unsigned int)this->percent_cpu);
       } else if (this->percent_cpu > 99.9) {
-         xSnprintf(buffer, n, "%3d. ", (unsigned int)this->percent_cpu); 
+         xSnprintf(buffer, n, "%3u. ", (unsigned int)this->percent_cpu);
       } else {
          xSnprintf(buffer, n, "%4.1f ", this->percent_cpu);
       }
@@ -390,7 +242,7 @@ void Process_writeField(Process* this, RichString* str, ProcessField field) {
    }
    case PERCENT_MEM: {
       if (this->percent_mem > 99.9) {
-         xSnprintf(buffer, n, "100. "); 
+         xSnprintf(buffer, n, "100. ");
       } else {
          xSnprintf(buffer, n, "%4.1f ", this->percent_mem);
       }
@@ -414,11 +266,16 @@ void Process_writeField(Process* this, RichString* str, ProcessField field) {
             if (indent & (1U << i))
                maxIndent = i+1;
           for (int i = 0; i < maxIndent - 1; i++) {
-            int written;
+            int written, ret;
             if (indent & (1 << i))
-               written = snprintf(buf, n, "%s  ", CRT_treeStr[TREE_STR_VERT]);
+               ret = snprintf(buf, n, "%s  ", CRT_treeStr[TREE_STR_VERT]);
             else
-               written = snprintf(buf, n, "   ");
+               ret = snprintf(buf, n, "   ");
+            if (ret < 0 || ret >= n) {
+               written = n;
+            } else {
+               written = ret;
+            }
             buf += written;
             n -= written;
          }
@@ -466,7 +323,7 @@ void Process_writeField(Process* this, RichString* str, ProcessField field) {
       }
       break;
    }
-   case ST_UID: xSnprintf(buffer, n, "%4d ", this->st_uid); break;
+   case ST_UID: xSnprintf(buffer, n, "%5d ", this->st_uid); break;
    case TIME: Process_printTime(str, this->time); return;
    case TGID: xSnprintf(buffer, n, Process_pidFormat, this->tgid); break;
    case TPGID: xSnprintf(buffer, n, Process_pidFormat, this->tpgid); break;
@@ -544,14 +401,15 @@ bool Process_setPriority(Process* this, int priority) {
    return (err == 0);
 }
 
-bool Process_changePriorityBy(Process* this, int delta) {
-   return Process_setPriority(this, this->nice + delta);
+bool Process_changePriorityBy(Process* this, Arg delta) {
+   return Process_setPriority(this, this->nice + delta.i);
 }
 
-void Process_sendSignal(Process* this, int sgn) {
+bool Process_sendSignal(Process* this, Arg sgn) {
    CRT_dropPrivileges();
-   kill(this->pid, (int) sgn);
+   bool ok = (kill(this->pid, sgn.i) == 0);
    CRT_restorePrivileges();
+   return ok;
 }
 
 long Process_pidCompare(const void* v1, const void* v2) {
