@@ -16,33 +16,6 @@ in the source distribution for its full text.
 #include <stdlib.h>
 #include <stdbool.h>
 
-/*{
-#include "FunctionBar.h"
-#include "Vector.h"
-#include "Header.h"
-#include "Settings.h"
-#include "Panel.h"
-
-typedef enum Orientation_ {
-   VERTICAL,
-   HORIZONTAL
-} Orientation;
-
-typedef struct ScreenManager_ {
-   int x1;
-   int y1;
-   int x2;
-   int y2;
-   Orientation orientation;
-   Vector* panels;
-   int panelCount;
-   const Header* header;
-   const Settings* settings;
-   bool owner;
-   bool allowFocusChange;
-} ScreenManager;
-
-}*/
 
 ScreenManager* ScreenManager_new(int x1, int y1, int x2, int y2, Orientation orientation, const Header* header, const Settings* settings, bool owner) {
    ScreenManager* this;
@@ -145,14 +118,12 @@ static void checkRecalculation(ScreenManager* this, double* oldTime, int* sortTi
 }
 
 static void ScreenManager_drawPanels(ScreenManager* this, int focus) {
-   int nPanels = this->panelCount;
+   const int nPanels = this->panelCount;
    for (int i = 0; i < nPanels; i++) {
       Panel* panel = (Panel*) Vector_get(this->panels, i);
       Panel_draw(panel, i == focus);
-      if (i < nPanels) {
-         if (this->orientation == HORIZONTAL) {
-            mvvline(panel->y, panel->x+panel->w, ' ', panel->h+1);
-         }
+      if (this->orientation == HORIZONTAL) {
+         mvvline(panel->y, panel->x+panel->w, ' ', panel->h+1);
       }
    }
 }
@@ -165,7 +136,7 @@ static Panel* setCurrentPanel(Panel* panel) {
 void ScreenManager_run(ScreenManager* this, Panel** lastFocus, int* lastKey) {
    bool quit = false;
    int focus = 0;
-   
+
    Panel* panelFocus = setCurrentPanel((Panel*) Vector_get(this->panels, focus));
 
    double oldTime = 0.0;
@@ -183,7 +154,7 @@ void ScreenManager_run(ScreenManager* this, Panel** lastFocus, int* lastKey) {
       if (this->header) {
          checkRecalculation(this, &oldTime, &sortTimeout, &redraw, &rescan, &timedOut);
       }
-      
+
       if (redraw) {
          ScreenManager_drawPanels(this, focus);
       }
@@ -193,7 +164,7 @@ void ScreenManager_run(ScreenManager* this, Panel** lastFocus, int* lastKey) {
       ch = getch();
 
       HandlerResult result = IGNORED;
-      if (ch == KEY_MOUSE) {
+      if (ch == KEY_MOUSE && this->settings->enableMouse) {
          ch = ERR;
          MEVENT mevent;
          int ok = getmouse(&mevent);
@@ -271,7 +242,7 @@ void ScreenManager_run(ScreenManager* this, Panel** lastFocus, int* lastKey) {
          quit = true;
          continue;
       }
-      
+
       switch (ch) {
       case KEY_RESIZE:
       {
