@@ -10,12 +10,9 @@ in the source distribution for its full text.
 #include "Platform.h"
 #include "CRT.h"
 
-/*{
-#include "Meter.h"
-}*/
 
 int TasksMeter_attributes[] = {
-   CPU_KERNEL, PROCESS_THREAD, PROCESS, TASKS_RUNNING
+   CPU_SYSTEM, PROCESS_THREAD, PROCESS, TASKS_RUNNING
 };
 
 static void TasksMeter_updateValues(Meter* this, char* buffer, int len) {
@@ -23,7 +20,7 @@ static void TasksMeter_updateValues(Meter* this, char* buffer, int len) {
    this->values[0] = pl->kernelThreads;
    this->values[1] = pl->userlandThreads;
    this->values[2] = pl->totalTasks - pl->kernelThreads - pl->userlandThreads;
-   this->values[3] = MIN(pl->runningTasks, pl->cpuCount);
+   this->values[3] = MINIMUM(pl->runningTasks, pl->cpuCount);
    if (pl->totalTasks > this->total) {
       this->total = pl->totalTasks;
    }
@@ -37,9 +34,9 @@ static void TasksMeter_display(Object* cast, RichString* out) {
    Meter* this = (Meter*)cast;
    Settings* settings = this->pl->settings;
    char buffer[20];
-   
+
    int processes = (int) this->values[2];
-   
+
    xSnprintf(buffer, sizeof(buffer), "%d", processes);
    RichString_write(out, CRT_colors[METER_VALUE], buffer);
    int threadValueColor = CRT_colors[METER_VALUE];
@@ -76,7 +73,7 @@ MeterClass TasksMeter_class = {
    .defaultMode = TEXT_METERMODE,
    .maxItems = 4,
    .total = 100.0,
-   .attributes = TasksMeter_attributes, 
+   .attributes = TasksMeter_attributes,
    .name = "Tasks",
    .uiName = "Task counter",
    .caption = "Tasks: "
