@@ -8,7 +8,6 @@ in the source distribution for its full text.
 #include "TraceScreen.h"
 
 #include "CRT.h"
-#include "InfoScreen.h"
 #include "ProcessList.h"
 #include "ListItem.h"
 #include "IncSet.h"
@@ -27,21 +26,6 @@ in the source distribution for its full text.
 #include <sys/wait.h>
 #include <signal.h>
 
-/*{
-#include "InfoScreen.h"
-
-typedef struct TraceScreen_ {
-   InfoScreen super;
-   bool tracing;
-   int fdpair[2];
-   int child;
-   FILE* strace;
-   int fd_strace;
-   bool contLine;
-   bool follow;
-} TraceScreen;
-
-}*/
 
 static const char* const TraceScreenFunctions[] = {"Search ", "Filter ", "AutoScroll ", "Stop Tracing   ", "Done   ", NULL};
 
@@ -101,14 +85,15 @@ bool TraceScreen_forkTracer(TraceScreen* this) {
       int ok = fcntl(this->fdpair[1], F_SETFL, O_NONBLOCK);
       if (ok != -1) {
          xSnprintf(buffer, sizeof(buffer), "%d", this->super.process->pid);
-         execlp("strace", "strace", "-p", buffer, NULL);
+         execlp("strace", "strace", "-T", "-tt", "-s", "512", "-p", buffer, NULL);
       }
       const char* message = "Could not execute 'strace'. Please make sure it is available in your $PATH.";
       ssize_t written = write(this->fdpair[1], message, strlen(message));
       (void) written;
       exit(1);
    }
-   fcntl(this->fdpair[0], F_SETFL, O_NONBLOCK);
+   int ok = fcntl(this->fdpair[0], F_SETFL, O_NONBLOCK);
+   if (ok == -1) return false;
    this->strace = fdopen(this->fdpair[0], "r");
    this->fd_strace = fileno(this->strace);
    return true;
