@@ -15,21 +15,6 @@ in the source distribution for its full text.
 
 #include <mach/mach.h>
 
-/*{
-#include "Settings.h"
-#include "DarwinProcessList.h"
-
-#include <sys/sysctl.h>
-
-typedef struct DarwinProcess_ {
-   Process super;
-
-   uint64_t utime;
-   uint64_t stime;
-   bool taskAccess;
-} DarwinProcess;
-
-}*/
 
 ProcessClass DarwinProcess_class = {
    .super = {
@@ -212,7 +197,7 @@ ERROR_B:
 ERROR_A:
    retval = xStrdup(k->kp_proc.p_comm);
    *basenameOffset = strlen(retval);
-   
+
    return retval;
 }
 
@@ -302,11 +287,11 @@ void DarwinProcess_setFromLibprocPidinfo(DarwinProcess *proc, DarwinProcessList
 void DarwinProcess_scanThreads(DarwinProcess *dp) {
    Process* proc = (Process*) dp;
    kern_return_t ret;
-   
+
    if (!dp->taskAccess) {
       return;
    }
-   
+
    if (proc->state == 'Z') {
       return;
    }
@@ -317,7 +302,7 @@ void DarwinProcess_scanThreads(DarwinProcess *dp) {
       dp->taskAccess = false;
       return;
    }
-   
+
    task_info_data_t tinfo;
    mach_msg_type_number_t task_info_count = TASK_INFO_MAX;
    ret = task_info(port, TASK_BASIC_INFO, (task_info_t) tinfo, &task_info_count);
@@ -325,7 +310,7 @@ void DarwinProcess_scanThreads(DarwinProcess *dp) {
       dp->taskAccess = false;
       return;
    }
-   
+
    thread_array_t thread_list;
    mach_msg_type_number_t thread_count;
    ret = task_threads(port, &thread_list, &thread_count);
@@ -334,7 +319,7 @@ void DarwinProcess_scanThreads(DarwinProcess *dp) {
       mach_port_deallocate(mach_task_self(), port);
       return;
    }
-   
+
    integer_t run_state = 999;
    for (unsigned int i = 0; i < thread_count; i++) {
       thread_info_data_t thinfo;
