@@ -9,6 +9,8 @@ in the source distribution for its full text.
 #include "DarwinProcess.h"
 #include "DarwinProcessList.h"
 #include "CRT.h"
+#include "zfs/ZfsArcStats.h"
+#include "zfs/openzfs_sysctl.h"
 
 #include <stdlib.h>
 #include <string.h>
@@ -52,25 +54,6 @@ int CompareKernelVersion(short int major, short int minor, short int component)
     return 0;
 }
 
-/*{
-#include "ProcessList.h"
-#include <mach/mach_host.h>
-#include <sys/sysctl.h>
-
-typedef struct DarwinProcessList_ {
-   ProcessList super;
-
-   host_basic_info_data_t host_info;
-   vm_statistics_data_t vm_stats;
-   processor_cpu_load_info_t prev_load;
-   processor_cpu_load_info_t curr_load;
-   uint64_t kernel_threads;
-   uint64_t user_threads;
-   uint64_t global_diff;
-} DarwinProcessList;
-
-}*/
-
 void ProcessList_getHostInfo(host_basic_info_data_t *p) {
    mach_msg_type_number_t info_size = HOST_BASIC_INFO_COUNT;
 
@@ -84,9 +67,8 @@ void ProcessList_freeCPULoadInfo(processor_cpu_load_info_t *p) {
        if(0 != munmap(*p, vm_page_size)) {
            CRT_fatalError("Unable to free old CPU load information\n");
        }
+       *p = NULL;
    }
-
-   *p = NULL;
 }
 
 unsigned ProcessList_allocateCPULoadInfo(processor_cpu_load_info_t *p) {
@@ -132,11 +114,11 @@ struct kinfo_proc *ProcessList_getKInfoProcs(size_t *count) {
    return processes;
 }
 
-
-ProcessList* ProcessList_new(UsersTable* usersTable, Hashtable* pidWhiteList, uid_t userId) {
+ProcessList* ProcessList_new(UsersTable* usersTable, Hashtable* pidMatchList, uid_t userId) {
+   size_t len;
    DarwinProcessList* this = xCalloc(1, sizeof(DarwinProcessList));
 
-   ProcessList_init(&this->super, Class(Process), usersTable, pidWhiteList, userId);
+   ProcessList_init(&this->super, Class(Process), usersTable, pidMatchList, userId);
 
    /* Initialize the CPU information */
    this->super.cpuCount = ProcessList_allocateCPULoadInfo(&this->prev_load);
@@ -146,6 +128,10 @@ ProcessList* ProcessList_new(UsersTable* usersTable, Hashtable* pidWhiteList, ui
    /* Initialize the VM statistics */
    ProcessList_getVMStats(&this->vm_stats);
 
+   /* Initialize the ZFS kstats, if zfs.kext loaded */
+   openzfs_sysctl_init(&this->zfs);
+   openzfs_sysctl_updateArcStats(&this->zfs);
+
    this->super.kernelThreads = 0;
    this->super.userlandThreads = 0;
    this->super.totalTasks = 0;
@@ -174,6 +160,7 @@ void ProcessList_goThroughEntries(ProcessList* super) {
     dpl->prev_load = dpl->curr_load;
     ProcessList_allocateCPULoadInfo(&dpl->curr_load);
     ProcessList_getVMStats(&dpl->vm_stats);
+    openzfs_sysctl_updateArcStats(&dpl->zfs);
 
     /* Get the time difference */
     dpl->global_diff = 0;
