@@ -8,6 +8,8 @@ in the source distribution for its full text.
 #include "ProcessList.h"
 #include "FreeBSDProcessList.h"
 #include "FreeBSDProcess.h"
+#include "zfs/ZfsArcStats.h"
+#include "zfs/openzfs_sysctl.h"
 
 #include <unistd.h>
 #include <stdlib.h>
@@ -18,55 +20,10 @@ in the source distribution for its full text.
 #include <fcntl.h>
 #include <limits.h>
 #include <string.h>
+#include <time.h>
 
-/*{
-
-#include <kvm.h>
-#include <sys/param.h>
-#include <sys/jail.h>
-#include <sys/uio.h>
-#include <sys/resource.h>
-
-#define JAIL_ERRMSGLEN	1024
 char jail_errmsg[JAIL_ERRMSGLEN];
 
-typedef struct CPUData_ {
-
-   double userPercent;
-   double nicePercent;
-   double systemPercent;
-   double irqPercent;
-   double idlePercent;
-   double systemAllPercent;
-
-} CPUData;
-
-typedef struct FreeBSDProcessList_ {
-   ProcessList super;
-   kvm_t* kd;
-
-   int zfsArcEnabled;
-
-   unsigned long long int memWire;
-   unsigned long long int memActive;
-   unsigned long long int memInactive;
-   unsigned long long int memFree;
-   unsigned long long int memZfsArc;
-
-
-   CPUData* cpus;
-
-   unsigned long   *cp_time_o;
-   unsigned long   *cp_time_n;
-
-   unsigned long  *cp_times_o;
-   unsigned long  *cp_times_n;
-
-} FreeBSDProcessList;
-
-}*/
-
-
 static int MIB_hw_physmem[2];
 static int MIB_vm_stats_vm_v_page_count[4];
 static int pageSize;
@@ -80,18 +37,16 @@ static int MIB_vm_stats_vm_v_free_count[4];
 
 static int MIB_vfs_bufspace[2];
 
-static int MIB_kstat_zfs_misc_arcstats_size[5];
-
 static int MIB_kern_cp_time[2];
 static int MIB_kern_cp_times[2];
 static int kernelFScale;
 
-ProcessList* ProcessList_new(UsersTable* usersTable, Hashtable* pidWhiteList, uid_t userId) {
+ProcessList* ProcessList_new(UsersTable* usersTable, Hashtable* pidMatchList, uid_t userId) {
    size_t len;
    char errbuf[_POSIX2_LINE_MAX];
    FreeBSDProcessList* fpl = xCalloc(1, sizeof(FreeBSDProcessList));
    ProcessList* pl = (ProcessList*) fpl;
-   ProcessList_init(pl, Class(FreeBSDProcess), usersTable, pidWhiteList, userId);
+   ProcessList_init(pl, Class(FreeBSDProcess), usersTable, pidMatchList, userId);
 
    // physical memory in system: hw.physmem
    // physical page size: hw.pagesize
@@ -118,15 +73,8 @@ ProcessList* ProcessList_new(UsersTable* usersTable, Hashtable* pidWhiteList, ui
 
    len = 2; sysctlnametomib("vfs.bufspace", MIB_vfs_bufspace, &len);
 
-   len = sizeof(fpl->memZfsArc);
-   if (sysctlbyname("kstat.zfs.misc.arcstats.size", &fpl->memZfsArc, &len,
-	    NULL, 0) == 0 && fpl->memZfsArc != 0) {
-      sysctlnametomib("kstat.zfs.misc.arcstats.size", MIB_kstat_zfs_misc_arcstats_size, &len);
-		  fpl->zfsArcEnabled = 1;
-   } else {
-		  fpl->zfsArcEnabled = 0;
-   }
-
+   openzfs_sysctl_init(&fpl->zfs);
+   openzfs_sysctl_updateArcStats(&fpl->zfs);
 
    int smp = 0;
    len = sizeof(smp);
@@ -151,10 +99,10 @@ ProcessList* ProcessList_new(UsersTable* usersTable, Hashtable* pidWhiteList, ui
    fpl->cp_time_n = xCalloc(cpus, sizeof_cp_time_array);
    len = sizeof_cp_time_array;
 
-   // fetch intial single (or average) CPU clicks from kernel
+   // fetch initial single (or average) CPU clicks from kernel
    sysctl(MIB_kern_cp_time, 2, fpl->cp_time_o, &len, NULL, 0);
 
-   // on smp box, fetch rest of intial CPU's clicks
+   // on smp box, fetch rest of initial CPU's clicks
    if (cpus > 1) {
       len = 2; sysctlnametomib("kern.cp_times", MIB_kern_cp_times, &len);
       fpl->cp_times_o = xCalloc(cpus, sizeof_cp_time_array);
@@ -163,7 +111,7 @@ ProcessList* ProcessList_new(UsersTable* usersTable, Hashtable* pidWhiteList, ui
       sysctl(MIB_kern_cp_times, 2, fpl->cp_times_o, &len, NULL, 0);
    }
 
-   pl->cpuCount = MAX(cpus, 1);
+   pl->cpuCount = MAXIMUM(cpus, 1);
 
    if (cpus == 1 ) {
      fpl->cpus = xRealloc(fpl->cpus, sizeof(CPUData));
@@ -175,7 +123,7 @@ ProcessList* ProcessList_new(UsersTable* usersTable, Hashtable* pidWhiteList, ui
 
    len = sizeof(kernelFScale);
    if (sysctlbyname("kern.fscale", &kernelFScale, &len, NULL, 0) == -1) {
-      //sane default for kernel provded CPU precentage scaling, at least on x86 machines, in case this sysctl call failed
+      //sane default for kernel provided CPU percentage scaling, at least on x86 machines, in case this sysctl call failed
       kernelFScale = 2048;
    }
 
@@ -296,35 +244,44 @@ static inline void FreeBSDProcessList_scanMemoryInfo(ProcessList* pl) {
    //
    // htop_used   = active + (wired - arc)
    // htop_cache  = buffers + cache + arc
-   size_t len = sizeof(pl->totalMem);
+   u_long totalMem;
+   u_int memActive, memWire, cachedMem;
+   long buffersMem;
+   uint64_t memZfsArc;
+   size_t len;
 
    //disabled for now, as it is always smaller than phycal amount of memory...
    //...to avoid "where is my memory?" questions
    //sysctl(MIB_vm_stats_vm_v_page_count, 4, &(pl->totalMem), &len, NULL, 0);
    //pl->totalMem *= pageSizeKb;
-   sysctl(MIB_hw_physmem, 2, &(pl->totalMem), &len, NULL, 0);
-   pl->totalMem /= 1024;
+   len = sizeof(totalMem);
+   sysctl(MIB_hw_physmem, 2, &(totalMem), &len, NULL, 0);
+   totalMem /= 1024;
+   pl->totalMem = totalMem;
 
-   sysctl(MIB_vm_stats_vm_v_active_count, 4, &(fpl->memActive), &len, NULL, 0);
-   fpl->memActive *= pageSizeKb;
+   len = sizeof(memActive);
+   sysctl(MIB_vm_stats_vm_v_active_count, 4, &(memActive), &len, NULL, 0);
+   memActive *= pageSizeKb;
+   fpl->memActive = memActive;
 
-   sysctl(MIB_vm_stats_vm_v_wire_count, 4, &(fpl->memWire), &len, NULL, 0);
-   fpl->memWire *= pageSizeKb;
+   len = sizeof(memWire);
+   sysctl(MIB_vm_stats_vm_v_wire_count, 4, &(memWire), &len, NULL, 0);
+   memWire *= pageSizeKb;
+   fpl->memWire = memWire;
 
-   sysctl(MIB_vfs_bufspace, 2, &(pl->buffersMem), &len, NULL, 0);
-   pl->buffersMem /= 1024;
+   len = sizeof(buffersMem);
+   sysctl(MIB_vfs_bufspace, 2, &(buffersMem), &len, NULL, 0);
+   buffersMem /= 1024;
+   pl->buffersMem = buffersMem;
 
-   sysctl(MIB_vm_stats_vm_v_cache_count, 4, &(pl->cachedMem), &len, NULL, 0);
-   pl->cachedMem *= pageSizeKb;
+   len = sizeof(cachedMem);
+   sysctl(MIB_vm_stats_vm_v_cache_count, 4, &(cachedMem), &len, NULL, 0);
+   cachedMem *= pageSizeKb;
+   pl->cachedMem = cachedMem;
 
-   if (fpl->zfsArcEnabled) {
-      len = sizeof(fpl->memZfsArc);
-      sysctl(MIB_kstat_zfs_misc_arcstats_size, 5, &(fpl->memZfsArc), &len , NULL, 0);
-      fpl->memZfsArc /= 1024;
-      fpl->memWire -= fpl->memZfsArc;
-      pl->cachedMem += fpl->memZfsArc;
-      // maybe when we learn how to make custom memory meter
-      // we could do custom arc breakdown?
+   if (fpl->zfs.enabled) {
+      fpl->memWire -= fpl->zfs.size;
+      pl->cachedMem += fpl->zfs.size;
    }
 
    pl->usedMem = fpl->memActive + fpl->memWire;
@@ -398,7 +355,7 @@ char* FreeBSDProcessList_readJailName(struct kinfo_proc* kproc) {
       jid = jail_get(jiov, 6, 0);
       if (jid < 0) {
          if (!jail_errmsg[0])
-            snprintf(jail_errmsg, JAIL_ERRMSGLEN, "jail_get: %s", strerror(errno));
+            xSnprintf(jail_errmsg, JAIL_ERRMSGLEN, "jail_get: %s", strerror(errno));
             return NULL;
       } else if (jid == kproc->ki_jid) {
          jname = xStrdup(jnamebuf);
@@ -422,17 +379,22 @@ void ProcessList_goThroughEntries(ProcessList* this) {
    bool hideKernelThreads = settings->hideKernelThreads;
    bool hideUserlandThreads = settings->hideUserlandThreads;
 
+   openzfs_sysctl_updateArcStats(&fpl->zfs);
    FreeBSDProcessList_scanMemoryInfo(this);
    FreeBSDProcessList_scanCPUTime(this);
 
    int cpus = this->cpuCount;
    int count = 0;
-   struct kinfo_proc* kprocs = kvm_getprocs(fpl->kd, KERN_PROC_ALL, 0, &count);
+   struct kinfo_proc* kprocs = kvm_getprocs(fpl->kd, KERN_PROC_PROC, 0, &count);
+
+   struct timeval tv;
+   gettimeofday(&tv, NULL);
 
    for (int i = 0; i < count; i++) {
       struct kinfo_proc* kproc = &kprocs[i];
       bool preExisting = false;
       bool isIdleProcess = false;
+      struct tm date;
       Process* proc = ProcessList_getProcess(this, kproc->ki_pid, &preExisting, (Process_New) FreeBSDProcess_new);
       FreeBSDProcess* fp = (FreeBSDProcess*) proc;
 
@@ -459,17 +421,17 @@ void ProcessList_goThroughEntries(ProcessList* this) {
          fp->jname = FreeBSDProcessList_readJailName(kproc);
       } else {
          if(fp->jid != kproc->ki_jid) {
-            // proces can enter jail anytime
+            // process can enter jail anytime
             fp->jid = kproc->ki_jid;
             free(fp->jname);
             fp->jname = FreeBSDProcessList_readJailName(kproc);
          }
          if (proc->ppid != kproc->ki_ppid) {
-            // if there are reapers in the system, proces can get reparented anytime
+            // if there are reapers in the system, process can get reparented anytime
             proc->ppid = kproc->ki_ppid;
          }
          if(proc->st_uid != kproc->ki_uid) {
-            // some proceses change users (eg. to lower privs)
+            // some processes change users (eg. to lower privs)
             proc->st_uid = kproc->ki_uid;
             proc->user = UsersTable_getRef(this->usersTable, proc->st_uid);
          }
@@ -495,10 +457,6 @@ void ProcessList_goThroughEntries(ProcessList* this) {
             isIdleProcess = true;
          }
       }
-      if (isIdleProcess == false && proc->percent_cpu >= 99.8) {
-         // don't break formatting
-         proc->percent_cpu = 99.8;
-      }
 
       proc->priority = kproc->ki_pri.pri_level - PZERO;
 
@@ -527,6 +485,9 @@ void ProcessList_goThroughEntries(ProcessList* this) {
          this->kernelThreads++;
       }
 
+      (void) localtime_r((time_t*) &proc->starttime_ctime, &date);
+      strftime(proc->starttime_show, 7, ((proc->starttime_ctime > tv.tv_sec - 86400) ? "%R " : "%b%d "), &date);
+
       this->totalTasks++;
       if (proc->state == 'R')
          this->runningTasks++;
